@@ -2,12 +2,11 @@ import unittest
 import os
 import logging
 from pds_github_util.requirements.requirements import Requirements
+from pds_github_util.utils.tokens import GITHUB_TOKEN
 
 logging.basicConfig(level=logging.DEBUG)
 logger = logging.getLogger(__name__)
 
-GITHUB_TOKEN = os.environ.get("GITHUB_TOKEN")
-
 class MyTestCase(unittest.TestCase):
     def test_get_requirements(self):
         requirements = Requirements('NASA-PDS', 'pds-doi-service', token=GITHUB_TOKEN)
